==> chaosmesh-model-5.0.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodNetworkChaosBuilder extends PodNetworkChaosFluentImpl<PodNetworkChaosBuilder> implements VisitableBuilder<PodNetworkChaos,PodNetworkChaosBuilder> {

    PodNetworkChaosFluent<?> fluent;
    Boolean validationEnabled;

    public PodNetworkChaosBuilder() {
        this(true);
    }

    public PodNetworkChaosBuilder(Boolean validationEnabled) {
        this(new PodNetworkChaos(), validationEnabled);
    }

    public PodNetworkChaosBuilder(PodNetworkChaosFluent<?> fluent) {
        this(fluent, true);
    }

    public PodNetworkChaosBuilder(PodNetworkChaosFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PodNetworkChaos(), validationEnabled);
    }

    public PodNetworkChaosBuilder(PodNetworkChaosFluent<?> fluent,PodNetworkChaos instance) {
        this(fluent, instance, true);
    }

    public PodNetworkChaosBuilder(PodNetworkChaosFluent<?> fluent,PodNetworkChaos instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public PodNetworkChaosBuilder(PodNetworkChaos instance) {
        this(instance,true);
    }

    public PodNetworkChaosBuilder(PodNetworkChaos instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditablePodNetworkChaos build() {
        EditablePodNetworkChaos buildable = new EditablePodNetworkChaos(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PodNetworkChaosBuilder that = (PodNetworkChaosBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> chaosmesh-model-5.3.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodNetworkChaosBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class PodNetworkChaosBuilder extends PodNetworkChaosFluentImpl<PodNetworkChaosBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<PodNetworkChaos,PodNetworkChaosBuilder> {

    PodNetworkChaosFluent<?> fluent;
    Boolean validationEnabled;

    public PodNetworkChaosBuilder() {
        this(true);
    }

    public PodNetworkChaosBuilder(Boolean validationEnabled) {
        this(new PodNetworkChaos(), validationEnabled);
    }

    public PodNetworkChaosBuilder(PodNetworkChaosFluent<?> fluent) {
        this(fluent, true);
    }

    public PodNetworkChaosBuilder(PodNetworkChaosFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new PodNetworkChaos(), validationEnabled);
    }

    public PodNetworkChaosBuilder(PodNetworkChaosFluent<?> fluent,PodNetworkChaos instance) {
        this(fluent, instance, true);
    }

    public PodNetworkChaosBuilder(PodNetworkChaosFluent<?> fluent,PodNetworkChaos instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        fluent.withSpec(instance.getSpec()); 
        fluent.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public PodNetworkChaosBuilder(PodNetworkChaos instance) {
        this(instance,true);
    }

    public PodNetworkChaosBuilder(PodNetworkChaos instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.withSpec(instance.getSpec()); 
        this.withStatus(instance.getStatus()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.chaosmesh.v1alpha1.EditablePodNetworkChaos build() {
        EditablePodNetworkChaos buildable = new EditablePodNetworkChaos(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        PodNetworkChaosBuilder that = (PodNetworkChaosBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
